.. _changelog:

=========
CHANGELOG
=========


.. _changelog-v0.0.7:

v0.0.7 (2025-02-26)
===================

Unknown
-------

* Merge branch 'main' of github.com:starccato/starccato_sampler (`2220781`_)

.. _2220781: https://github.com/starccato/starccato_sampler/commit/2220781cc01b1ed273760fdb21b96f6ee5a5b1e4


.. _changelog-v0.0.6:

v0.0.6 (2025-02-26)
===================

Bug Fixes
---------

* fix: hack for plotting z trues (`cea0b42`_)

* fix: adjust CI plotting (`af9876e`_)

Chores
------

* chore(release): 0.0.6 (`5d34ea5`_)

Unknown
-------

* plotting fixes (`be3f8a5`_)

.. _cea0b42: https://github.com/starccato/starccato_sampler/commit/cea0b428bc66e0977b0e69c33897bc8630e84107
.. _af9876e: https://github.com/starccato/starccato_sampler/commit/af9876e6a35cd613cbf25cbf91efdba2b25b3803
.. _5d34ea5: https://github.com/starccato/starccato_sampler/commit/5d34ea5f9b0748d40afea5ff661beb321055f25f
.. _be3f8a5: https://github.com/starccato/starccato_sampler/commit/be3f8a5fe612afac93e56de9974234284469b905


.. _changelog-v0.0.5:

v0.0.5 (2025-02-21)
===================

Chores
------

* chore(release): 0.0.5 (`1005fd1`_)

Unknown
-------

* Merge branch 'main' of github.com:starccato/starccato_sampler (`e4d4690`_)

.. _1005fd1: https://github.com/starccato/starccato_sampler/commit/1005fd1b9dee9a3b237bd27b40101517e3e2fbf8
.. _e4d4690: https://github.com/starccato/starccato_sampler/commit/e4d46905d3602d99d1289d8274a5ad0e627f3bef


.. _changelog-v0.0.4:

v0.0.4 (2025-02-19)
===================

Bug Fixes
---------

* fix: add more data to sampler output (`b6954b2`_)

Chores
------

* chore(release): 0.0.4 (`8730a23`_)

Unknown
-------

* Merge branch 'main' of github.com:starccato/starccato_sampler (`06b6ccc`_)

.. _b6954b2: https://github.com/starccato/starccato_sampler/commit/b6954b20d0472540624ea91636525ed114da2076
.. _8730a23: https://github.com/starccato/starccato_sampler/commit/8730a23df6b8eeebd29a34b7f5edd4e4b80f4cf4
.. _06b6ccc: https://github.com/starccato/starccato_sampler/commit/06b6cccc7b8f5f54b93f559e1f6a276c815c0de4


.. _changelog-v0.0.3:

v0.0.3 (2025-02-19)
===================

Bug Fixes
---------

* fix: remove gss (`fc6ce51`_)

Chores
------

* chore(release): 0.0.3 (`840a8d8`_)

Unknown
-------

* Merge branch 'main' of github.com:starccato/starccato_sampler (`43e37e8`_)

.. _fc6ce51: https://github.com/starccato/starccato_sampler/commit/fc6ce51aac15d45056035acf028774ca6628a0f5
.. _840a8d8: https://github.com/starccato/starccato_sampler/commit/840a8d81b22235b22c426a3f18d0c0a65738a717
.. _43e37e8: https://github.com/starccato/starccato_sampler/commit/43e37e82d8c7da483aba4824b4fbc54bed61824a


.. _changelog-v0.0.2:

v0.0.2 (2025-02-19)
===================

Bug Fixes
---------

* fix: remove harmonic dependancies (`f4e1f2d`_)

Chores
------

* chore(release): 0.0.2 (`f85ee6d`_)

Unknown
-------

* add notes (`3069337`_)

* Merge branch 'main' of github.com:starccato/starccato_sampler (`6d7dff7`_)

.. _f4e1f2d: https://github.com/starccato/starccato_sampler/commit/f4e1f2dcd850633e3bcaba2ed59918b98ba0d5dc
.. _f85ee6d: https://github.com/starccato/starccato_sampler/commit/f85ee6d2e73c6bf782d629f9780acd123662140c
.. _3069337: https://github.com/starccato/starccato_sampler/commit/306933712d30881097cad7c62d6bd975a8281940
.. _6d7dff7: https://github.com/starccato/starccato_sampler/commit/6d7dff774a28b5dc93dfa913b074baa736eb794f


.. _changelog-v0.0.1:

v0.0.1 (2025-02-18)
===================

Bug Fixes
---------

* fix: add analytical evidence (`b43f6f8`_)

* fix: edit description (`9dd8873`_)

Chores
------

* chore(release): 0.0.1 (`98c207f`_)

Unknown
-------

* init project (`89a4278`_)

* Initial commit (`88ede42`_)

.. _b43f6f8: https://github.com/starccato/starccato_sampler/commit/b43f6f8b6358e26884930f280397100e268fe929
.. _9dd8873: https://github.com/starccato/starccato_sampler/commit/9dd88736b267e275cfe9f65d937bc693863eb1b9
.. _98c207f: https://github.com/starccato/starccato_sampler/commit/98c207fbe717b4da1b32d38a516d37db3bc4f47b
.. _89a4278: https://github.com/starccato/starccato_sampler/commit/89a42788db798a39075879c91220dbb653c272cd
.. _88ede42: https://github.com/starccato/starccato_sampler/commit/88ede4295f39fa76d4d8782404cb2855f71bb4de
